Learn R Programming

outliertree (version 1.9.0)

print.outliertree: Print summary information from Outlier Tree model

Description

Displays general statistics from a fitted Outlier Tree model (same as `summary`). For printing the outliers discovered, use function `print` on the returned outliers (e.g. from `predict`), not on the model object iself.

Usage

# S3 method for outliertree
print(x, ...)

Value

The same input `x` that was passed (as `invisible`).

Arguments

x

An Outlier Tree model as produced by function `outlier.tree`.

...

Not used.

Details

Note that after loading a serialized object from `outlier.tree` through `readRDS` or `load`, it will only de-serialize the underlying C++ object upon running `predict` or `print`, so the first run will be slower, while subsequent runs will be faster as the C++ object will already be in-memory.