summary.outliertree: Print summary information from Outlier Tree model
Description
Displays general statistics from a fitted Outlier Tree model (same as `print`).
For printing the outliers discovered, use function `print` on the returned outliers
(e.g. from `predict`), not on the model object iself.
Usage
# S3 method for outliertree
summary(object, ...)
Value
The same input `object` that was passed (as `invisible`).
Arguments
- object
An Outlier Tree model as produced by function `outlier.tree`.
- ...
Not used.